Deskripsi singkat proyek Python yang luar biasa.

## Instalation

```bash
pip install mecs
```

## Example Usage

```python
# import package
from mecs import Stem

# Create stemmer
st = Stem.Stemmer()

# stem
term = "romana"
st.stemming(term)

print("lemma : ", st.lemma)
# roma'

print("prefix : ", st.prefix)
# None

print("suffix : ", st.suffix)
# na

print("nasal : ", st.nasal)
# None

```

## Demo

Live demo : https://www.demo.com

## Refrences

- Rachman, F. H., Ifada, N., Wahyuni, S., Ramadani, G. D., & Pawitra, A. (2022, November). ModifiedECS (mECS) Algorithm for Madurese-Indonesian Rule-Based Machine Translation. In _Proceedings of The 2022 International Conference of Science and Information Technology in Smart Administration (ICSINTESA)_ (pp. 51-56). IEEE. DOI: [10.1109/ICSINTESA56431.2022.10041470](https://doi.org/10.1109/ICSINTESA56431.2022.10041470)
- Ifada, N., Rachman, F. H., Syauqy, M. W. M. A., Wahyuni, S., & Pawitra, A. (2023). MadureseSet: Madurese-Indonesian Dataset. _Data in Brief, 48,_ 109035. DOI: [10.1016/j.dib.2023.109035](https://doi.org/10.1016/j.dib.2023.109035)
